@@ -55,7 +55,9 @@
 #'                    \code{m.bulk = FALSE}, i.e., the Monte Carlo standard error
 #'                    for the median is computed.
 #' @param split       logical: if \code{TRUE} (default), each MCMC chain is split
-#'                    in half before computing R-hat, ESS, and MCSE.
+#'                    in half before computing R-hat. Note that the argument
+#'                    \code{split} is always set to \code{FALSE} when computing
+#'                    ESS.
 #' @param rank        logical: if \code{TRUE} (default), rank-normalization is
 #'                    applied to the posterior draws before computing R-hat and
 #'                    ESS. Note that the argument \code{rank} is always set to
@@ -160,7 +162,7 @@
 #'      distribution (i.e, efficiency of the posterior mean), and the Tail-ESS
 #'      is useful measure for sampling efficiency in the tails of the distribution
 #'      (e.g., efficiency of tail quantile estimates). Note that by default, the
-#'      Tail-ESS is the minimum of the effective sample sizes for 5% and 95%
+#'      Tail-ESS is the minimum of the effective sample sizes for 2.5% and 97.5%
 #'      quantiles (\code{tail = c(0.025, 0.975)}). According to Kruschke (2015),
 #'      a rank-normalized ESS greater than 400 is usually sufficient to get a
 #'      stable estimate of the Monte Carlo standard error. However, a ESS of
@@ -570,19 +572,19 @@ blimp.bayes <- function(x, param = NULL,
       }
 
       # Bulk Effective Sample Size
-      x.b.ess <- .ess(x, split = split, rank = rank)
+      x.b.ess <- .ess(x, split = FALSE, rank = rank)
 
       # Tail Effective Sample Size
-      x.t.ess <- min(.ess(x <= quantile(x, ess.tail[1L]), split = split, rank = rank), .ess(x <= quantile(x, ess.tail[2L]), split = split, rank = rank))
+      x.t.ess <- min(.ess(x <= quantile(x, ess.tail[1L]), split = FALSE, rank = rank), .ess(x <= quantile(x, ess.tail[2L]), split = FALSE, rank = rank))
 
       # Bulk Monte Carlo Standard Error
       if (isTRUE(m.bulk)) {
 
-        x.b.mcse <- .mcse(x, quant = FALSE, split = split, rank = FALSE)
+        x.b.mcse <- .mcse(x, quant = FALSE, split = FALSE, rank = FALSE)
 
       } else {
 
-        x.b.mcse <- .mcse(x, quant = TRUE, prob = 0.50, split = split, rank = FALSE)
+        x.b.mcse <- .mcse(x, quant = TRUE, prob = 0.50, split = FALSE, rank = FALSE)
 
       }
 
